Welcome to ut-course-catalog's documentation!
=============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   contributing

.. toctree::
   :maxdepth: 2
   :caption: API Reference:

   ut_course_catalog

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
